<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:strip-space elements="*"/>
  <xsl:preserve-space elements="eg"/>
  <xsl:output indent="yes" method="xml" doctype-system="xml/1998/06/xmlspec-v20.dtd"/>
 <xsl:param name="maxdepth" select="3"/>
  <xsl:param name="spec" select="'XSLT'"/>
  <xsl:variable name="ws">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:variable>

  <xsl:template match="/">
    <xsl:apply-templates select="reqs/spec[@name=$spec]"/>
  </xsl:template>

  <xsl:template match="spec">
    <xsl:variable name="MM" select="format-number(@month,'00')"/>
    <xsl:variable name="DD" select="format-number(@day,'00')"/>
    <xsl:variable name="URL">
      <xsl:value-of select="@lev"/>
      <xsl:text>-</xsl:text>
      <xsl:value-of select="@abbrev-lower"/>
      <xsl:text>-</xsl:text>
      <xsl:value-of select="@year"/>
      <xsl:value-of select="$MM"/>
      <xsl:value-of select="$DD"/>
    </xsl:variable>
    <spec>
      <header>
	<title><xsl:value-of select="@name"/> Requirements</title>
	<version>Version <xsl:value-of select="@version"/></version>
	<w3c-designation><xsl:value-of select="$URL"/></w3c-designation>
	<w3c-doctype>
          <xsl:text>W3C </xsl:text>
            <xsl:call-template name="levelname">
              <xsl:with-param name="level" select="@lev"/>
            </xsl:call-template>
        </w3c-doctype>
	<pubdate>
	  <day><xsl:value-of select="number(@day)"/></day>
	  <month>
            <xsl:call-template name="monthname">
              <xsl:with-param name="monthnum" select="@month"/>
            </xsl:call-template>
          </month>
	  <year><xsl:value-of select="@year"/></year>
	</pubdate>
	<publoc>
	  <loc href="http://www.w3.org/TR/{@year}/{$URL}">
	    <xsl:text>http://www.w3.org/TR/</xsl:text>
	    <xsl:value-of select="@year"/>
	    <xsl:text>/</xsl:text>
	    <xsl:value-of select="$URL"/>
	  </loc>
	  <loc role="available-format" href="http://www.w3.org/TR/{@year}/{$URL}.xml">XML</loc>
	  <loc role="available-format" href="http://www.w3.org/TR/{@year}/{$URL}.html">HTML</loc>
	</publoc>
	<latestloc>
	  <loc href="http://www.w3.org/TR/{@year}/{$URL}">
	    <xsl:text>http://www.w3.org/TR/</xsl:text>
	    <xsl:value-of select="@year"/>
	    <xsl:text>/</xsl:text>
	    <xsl:value-of select="$URL"/>
	  </loc>
	</latestloc>
	<authlist>
          <xsl:apply-templates select="editor"/>
	</authlist>
	<status>

	  <p>This section describes the status of this document at the
	  time of its publication. Other documents may supersede this
	  document. The latest status of this document series is
	  maintained at the W3C. This document is the first public <xsl:value-of select="@name"/><xsl:text> </xsl:text><xsl:value-of select="@version"/> Requirements working draft. </p>

	  <p>This is a W3C Working Draft for review by W3C Members and
	  other interested parties. It is a draft document and may be
	  updated, replaced or made obsolete by other documents at any
	  time. It is inappropriate to use W3C Working Drafts as
	  reference material or to cite them as other than "work in
	  progress". This is work in progress and does not imply
	  endorsement by the <loc 
	  href="http://www.w3.org/Consortium/Member/List">W3C
	  membership</loc>.</p>
<xsl:if test='$spec="XPath"'>
	 <p>This document has been produced jointly as part of the <loc
	  href="http://www.w3.org/Style/Activity">W3C Style
	  Activity</loc> and the <loc href="http://www.w3.org/XML/">W3C XML Activity</loc>,
          following the procedures set out for the W3C
	  Process. The document has been written by the <loc
	  href="http://www.w3.org/Style/XSL/Group">XSL Working
	  Group</loc> and the <loc href="http://www.w3.org/XML/Group/Query"
          >XML Query Working Group</loc> ( <loc
	  href="http://cgi.w3.org/MemberAccess/AccessRequest">W3C
	  members only</loc>). The goals of the XSL Working Group are
	  discussed in the <loc
	  href="http://www.w3.org/Style/2000/xsl-charter.html">XSL
	  Working Group charter</loc>, and the goals of the XML Query Working
          Group are discussed in the <loc href="http://www.w3.org/1999/07/query-charter">XML 
          Query Working Group Charter</loc>.  

  This Working Draft represents the current thinking of the XSL
  Working Group and XML Query Working Group. The groups have consensus
  except in a few specific areas as noted below and the details of
  these areas are still under active discussion.  Nonetheless, we are
  publishing this draft to encourage early public feedback to the
  XPath 2.0 requirements process.

</p>
</xsl:if>
<xsl:if test='$spec="XSLT"'>
	 <p>This document has been produced as part of the <loc
	  href="http://www.w3.org/Style/Activity">W3C Style
	  activity</loc>, following the procedures set out for the W3C
	  Process. The document has been written by the <loc
	  href="http://www.w3.org/Style/XSL/Group">XSL Working
	  Group</loc> ( <loc
	  href="http://cgi.w3.org/MemberAccess/AccessRequest">W3C
	  members only</loc>). The goals of the XSL Working Group are
	  discussed in the <loc
	  href="http://www.w3.org/Style/2000/xsl-charter.html">XSL
	  Working Group charter</loc>.  The XSL Working Group feels that
	  the contents of this Working Draft are relatively stable, and
	  therefore encourages feedback on this version.</p>
</xsl:if>

	  <p>Comments on this document should be sent to the W3C mailing
	  list <loc
	  href="mailto:xsl-editors@w3.org">xsl-editors@w3.org</loc>
	  (archived at <loc
	  href="http://lists.w3.org/Archives/Public/xsl-editors/">
	  http://lists.w3.org/Archives/Public/xsl-editors/</loc>).  A
	  list of current W3C Recommendations and other technical
	  documents can be found at <loc
	  href="http://www.w3.org/TR/">http://www.w3.org/TR/</loc>.
	  </p>
	</status>
	<abstract>
	  <p>
	    <xsl:text>This document describes the requirements for the </xsl:text>
	    <xsl:value-of select="@name"/>
	    <xsl:text> </xsl:text>
	    <xsl:value-of select="@version"/>
	    <xsl:text> specification.</xsl:text>
	  </p>
	</abstract>
	<langusage>
	  <language id="EN">English</language>
	</langusage>
	<revisiondesc>
	  <slist>
	    <sitem>See RCS log for revision history.</sitem>
	  </slist>
	</revisiondesc>
      </header>
      <body>
        <div1>
          <head>Goals</head>
          <p>
            <xsl:value-of select="@name"/>
	    <xsl:text> </xsl:text>
	    <xsl:value-of select="@version"/>
            <xsl:text> has the following goals: </xsl:text>
          </p>
          <ulist>
            <xsl:for-each select="/reqs/goal">
              <item><xsl:value-of select="."/></item>
            </xsl:for-each>
          </ulist>
          <xsl:if test="$spec='XSLT'">
	    <p>
	      <xsl:text>In addition, the following are explicitly </xsl:text>
	      <emph>not</emph>
	      <xsl:text> goals:</xsl:text>
	      <ulist>
		<xsl:for-each select="/reqs/non-goal">
		  <item><xsl:value-of select="."/></item>
		</xsl:for-each>
	      </ulist>
	    </p>
          </xsl:if>
        </div1>
        <div1>
	  <head>Requirements</head>
	  <table width="100%" border="0" cellspacing="0">
	    <tbody>
	      <xsl:apply-templates select="req"/>
	    </tbody>
	  </table>
        </div1>
        <div1>
          <head>References</head>
            <blist>
              <xsl:for-each select="otherspec">
                <bibl><xsl:value-of select="."/>, <loc href="{@url}"><xsl:value-of select="@url"/></loc></bibl>
              </xsl:for-each>
            </blist>
        </div1>
      </body>
    </spec>
  </xsl:template>
 
  <xsl:template match="editor">
	  <author>
	    <name><xsl:value-of select="@name"/></name>
            <affiliation><xsl:value-of select="@affiliation"/></affiliation>
	    <email href="mailto:{@email}"><xsl:value-of select="@email"/></email>
	  </author>
  </xsl:template>

  <xsl:template match="req">
    <xsl:variable name="global-order" select="count(preceding::req) + count(ancestor::req) + 1"/>
    <tr role="class-r{$global-order mod 2}">
      <xsl:variable name="lev" select="count(ancestor::req)"/>
      <xsl:for-each select="ancestor::req">
        <td valign="top"><xsl:value-of select="$ws"/></td>
      </xsl:for-each>
      <td valign="top" align="right" >
        <emph role="bold"><xsl:number level="multiple" count="req" format="1.1 "/></emph>
      </td>
      <td colspan="{$maxdepth - $lev}">
        <emph role="underline.class-p{@pri}">
          <xsl:call-template name="priname">
            <xsl:with-param name="pri" select="@pri"/>
          </xsl:call-template>
          <xsl:text>&#160;</xsl:text>
          <xsl:value-of select="name"/>
        </emph>
<!--        <emph role="span.class-id">
          <xsl:text> (</xsl:text>
          <xsl:value-of select="@id"/>
          <xsl:text>)</xsl:text>
        </emph>
-->
        <emph role="br"/>
<!--        <p> -->
          <xsl:choose>
            <xsl:when test="not(desc) or desc=''">
              <i>No description provided</i>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="desc"/>
            </xsl:otherwise>
          </xsl:choose>
<!--        </p> -->
        <xsl:apply-templates select="*[not(self::req or self::desc or self::name)]"/>
     </td>
   </tr>
   <xsl:apply-templates select="req[3 > @pri]"/>
</xsl:template>

  <xsl:template name="monthname">
    <xsl:param name="monthnum"/>
    <xsl:variable name="month" select="number($monthnum)"/>
    <xsl:choose>
      <xsl:when test="$month=1">January</xsl:when>
      <xsl:when test="$month=2">February</xsl:when>
      <xsl:when test="$month=3">March</xsl:when>
      <xsl:when test="$month=4">April</xsl:when>
      <xsl:when test="$month=5">May</xsl:when>
      <xsl:when test="$month=6">June</xsl:when>
      <xsl:when test="$month=7">July</xsl:when>
      <xsl:when test="$month=8">August</xsl:when>
      <xsl:when test="$month=9">September</xsl:when>
      <xsl:when test="$month=10">October</xsl:when>
      <xsl:when test="$month=11">November</xsl:when>
      <xsl:when test="$month=12">December</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="levelname">
    <xsl:param name="level"/>
    <xsl:choose>
      <xsl:when test="$level='WD'">Working Draft</xsl:when>
      <xsl:when test="$level='LC'">Last Call Draft</xsl:when>
      <xsl:when test="$level='CR'">Candidate Recommendation</xsl:when>
      <xsl:when test="$level='PR'">Proposed Recommendation</xsl:when>
      <xsl:when test="$level='REC'">Recommendation</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="lit">
    <code><xsl:apply-templates/></code>
  </xsl:template>

  <xsl:template match="i">
    <emph><xsl:apply-templates/></emph>
  </xsl:template>

  <xsl:template match="issue">
    <issue id="{@id}"><xsl:apply-templates/></issue>
  </xsl:template>

  <xsl:template match="b">
    <emph role="bold"><xsl:apply-templates/></emph>
  </xsl:template>

  <xsl:template match="eg">
    <eg><xsl:apply-templates/></eg>
  </xsl:template>

  <xsl:template match="ul">
    <ulist><xsl:apply-templates/></ulist>
  </xsl:template>

  <xsl:template match="ol">
    <olist><xsl:apply-templates/></olist>
  </xsl:template>

  <xsl:template match="li">
    <item><xsl:apply-templates/></item>
  </xsl:template>

  <xsl:template match="url">
    <xspecref href="{@href}"><xsl:apply-templates/></xspecref>
  </xsl:template>

  <xsl:template match="ed">
    <ednote><edtext><xsl:apply-templates/></edtext></ednote>
  </xsl:template>

  <xsl:template match="specref">
    <xsl:variable name="spec" select="ancestor::spec/otherspec[@id=current()/@spec]"/>
    <xspecref href="{$spec/@url}"><xsl:value-of select="$spec"/></xspecref>
  </xsl:template>

  <xsl:template match="use-case">
    <table border="0">
      <tbody>
        <tr><td><emph role="underline.bold">Use Case</emph></td></tr>
        <tr><td><xsl:apply-templates/></td></tr>
      </tbody>
    </table>
  </xsl:template>

  <xsl:template match="use-case-solution"/>

 <xsl:template match="p">
   <p><xsl:apply-templates/></p>
 </xsl:template>

<!--
 <xsl:template match="desc/p | ed/p | use-case//p[preceding-sibling::p or following-sibling::p]"  priority="10">
   <xsl:apply-templates/>
 </xsl:template>
-->

 <xsl:template name="priname">
   <xsl:param name="pri"/>
   <xsl:choose>
     <xsl:when test="$pri=0">Must</xsl:when>
     <xsl:when test="$pri=1">Should</xsl:when>
     <xsl:when test="$pri=2">Could</xsl:when>
     <xsl:when test="$pri=3">Unplanned</xsl:when>
   </xsl:choose>
 </xsl:template>

</xsl:stylesheet>