<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:e="http://www.jclark.com/XSLT/ElementSyntax"
        exclude-result-prefixes="e"
>

<xsl:import href="xslt.xsl"/>
  <xsl:strip-space elements="*"/>
  <xsl:preserve-space elements="eg"/>
<xsl:output indent="yes" encoding="ISO-8859-1"/>

<xsl:template match="code/loc[@href='replaceable']">
  <i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template name="handle-class">
  <xsl:if test="@role and contains(@role,'class-')">
    <xsl:variable name="x" select="substring-after(@role,'class-')"/>
    <xsl:attribute name="class">
      <xsl:value-of select="substring-after(@role,'class-')"/>
    </xsl:attribute>
  </xsl:if>
</xsl:template>

<xsl:template match="emph">
  <xsl:choose>
    <xsl:when test="@role">
      <xsl:choose>
        <xsl:when test="contains(@role,'span')">
          <span><xsl:call-template name="handle-class"/><xsl:apply-templates/></span>
        </xsl:when>
        <xsl:when test="contains(@role,'bold') and contains(@role,'underline')">
          <u><b><xsl:call-template name="handle-class"/><xsl:apply-templates/></b></u>
        </xsl:when>
        <xsl:when test="contains(@role,'bold')">
          <b><xsl:call-template name="handle-class"/><xsl:apply-templates/></b>
        </xsl:when>
        <xsl:when test="@role='br'">
          <br/>
        </xsl:when>
        <xsl:when test="contains(@role,'underline')">
          <u><xsl:call-template name="handle-class"/><xsl:apply-templates/></u>
        </xsl:when>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      <i><xsl:apply-templates/></i>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="issue/p[emph[contains(.,'RESOLUTION:')]]">
  <br/><br/><xsl:apply-templates/>
</xsl:template>

<xsl:template match="issue/p/emph">
  <p><i><xsl:apply-templates/></i></p>
</xsl:template>

	<xsl:template match="ednote//p">
		<xsl:apply-templates/>
	</xsl:template>

<xsl:template match="issue">
        <center><table border="0" width="90%" cellspacing="0"><tr><td>
	<xsl:call-template name="insertID"/>
	<blockquote>
		<p>
		<b>Issue (<xsl:value-of select="substring-after(@id,'-')"/>)</b><br/>
		<xsl:apply-templates/>
		</p>
	</blockquote>
        </td></tr></table></center>
</xsl:template>

<xsl:template match="tr">
  <tr><xsl:call-template name="handle-class"/><xsl:apply-templates/></tr>
</xsl:template>

<xsl:template match="th">
  <th><xsl:apply-templates/></th>
</xsl:template>

<xsl:template match="td">
  <td>
    <xsl:if test="@colspan">
      <xsl:attribute name="colspan"><xsl:value-of select="@colspan"/></xsl:attribute>
    </xsl:if>
    <xsl:if test="@valign">
      <xsl:attribute name="valign"><xsl:value-of select="@valign"/></xsl:attribute>
    </xsl:if>
    <xsl:if test="@align">
      <xsl:attribute name="align"><xsl:value-of select="@align"/></xsl:attribute>
    </xsl:if>
    <xsl:apply-templates/>
  </td>
</xsl:template>

	<xsl:template match="eg">

         <div class="java-class"> 
		  <xsl:call-template name="br-replace">
                    <xsl:with-param name="text">
                      <xsl:call-template name="sp-replace">
                        <xsl:with-param name="text" select="."/>
                      </xsl:call-template>
                    </xsl:with-param>
                  </xsl:call-template>
		</div> 

        <xsl:if test="parent::item or (preceding-sibling::text() and following-sibling::text())"><br/></xsl:if>
	</xsl:template>


<xsl:template match="table">
  <table>
    <xsl:if test="@border">
      <xsl:attribute name="border"><xsl:value-of select="@border"/></xsl:attribute>
    </xsl:if>
    <xsl:if test="@cellspacing">
      <xsl:attribute name="cellspacing"><xsl:value-of select="@cellspacing"/></xsl:attribute>
    </xsl:if>
    <xsl:if test="@width">
      <xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
    </xsl:if>
    <xsl:apply-templates/>
  </table>
</xsl:template>

<!--
<xsl:template match="table">
<table border="1" cellpadding="3" cellspacing="0">
  <tr class="tabheader">
    <xsl:apply-templates select="tbody/tr/th"/>
  </tr>
  <xsl:apply-templates select="tbody/tr[td]"/>
</table>
</xsl:template>
-->

<!--
<xsl:template match="tr[td]">
  <tr class="row{position() mod 2}">
    <xsl:apply-templates select="td"/>
  </tr>
</xsl:template>
-->

<!-- 
<xsl:template match="td">
  <td><xsl:apply-templates/></td>
</xsl:template>
-->

<xsl:template match="th">
  <th nowrap=""><xsl:apply-templates/></th>
</xsl:template>

<xsl:template match="item/p[position()=1 and position()=last() 
                     and not(preceding-sibling::*) 
                     and not(following-sibling::*)]" priority="5">
  <xsl:apply-templates/>
</xsl:template>

	<xsl:template match="spec">
		<html>
		<head>
		<title>
		<xsl:value-of select="header/title"/>
		</title>
		<link rel="stylesheet" type="text/css"
                      href="{$w3}StyleSheets/TR/W3C-{substring-before(header/w3c-designation,'-')}"/>
		<!-- This stops Netscape 4.5 from messing up. -->
		<style type="text/css">
                <xsl:apply-templates select="." mode="css"/>
.tabheader { background-color: #e0e0e0 }
.row0 { background-color: #f0f0f0 }
.row1 { background-color: white }
.java-class { 
  font-family: monospace;
  white-space: pre; 
}
         .lit {font-family:monospace}
         .req {font-size:90%; font-weight:bold}
         .id  {font-size:80%}
         .p0  {color:red;  font-weight:bold}
         .p1  {color:blue;  font-weight:bold}
         .p2  {color:#999999;   font-weight:bold}
         .p3  {color:green; font-weight:bold}
         .r0  {background:white}
         .r1  {background:white}
         .s1  {margin-left: 20pt}
                </style>
		</head>
		<body>
			<xsl:apply-templates/>
           <xsl:if test="count(//issue[not(@role) or @role=''])>0">
                 <hr/>
                 <h1>Summary of Open Issues</h1>
                 <table border="1" cellspacing="0">
                   <tr class="tabheader">
                     <th align="center">Issue</th>
                     <th>Description</th>
                   </tr>
                   <xsl:for-each select="//issue[not(@role) or @role='']">
                   <tr class="row{position() mod 2}">
                     <td align="center"><a href="#{@id}" title="{substring-after(@id,'issue-')}"><xsl:value-of select="position()"/></a></td>
                     <td><xsl:apply-templates/></td>
                   </tr>
                   </xsl:for-each>
                 </table>
              </xsl:if>
		</body>
		</html>
	</xsl:template>

  <!-- Replace new lines with html <br> tags -->
  <xsl:template name="br-replace">
    <xsl:param name="text"/>
    <xsl:variable name="cr" select="'&#xa;'"/>
    <xsl:choose>
      <!-- If the value of the $text parameter contains a carriage return... -->
      <xsl:when test="contains($text,$cr)">
        <!-- Return the substring of $text before the carriage return -->
        <xsl:value-of select="substring-before($text,$cr)"/>
        <!-- And construct a <br/> element -->
        <br/>
        <!--
         | Then invoke this same br-replace template again, passing the
         | substring *after* the carriage return as the new "$text" to
         | consider for replacement
         +-->
        <xsl:call-template name="br-replace">
          <xsl:with-param name="text" select="substring-after($text,$cr)"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
   </xsl:choose>
  </xsl:template>
  <!-- Replace two consecutive spaces w/ 2 non-breaking spaces -->
  <xsl:template name="sp-replace">
    <xsl:param name="text"/>
    <!-- NOTE: There are two spaces   ** here below -->
    <xsl:variable name="sp"><xsl:text>  </xsl:text></xsl:variable>
    <xsl:choose>
      <xsl:when test="contains($text,$sp)">
        <xsl:value-of select="substring-before($text,$sp)"/>
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:call-template name="sp-replace">
          <xsl:with-param name="text" select="substring-after($text,$sp)"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$text"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


</xsl:stylesheet>
